@@ -35,7 +35,7 @@ var searchData=
   ['cartesiancoordinatesystem2d_2eidl_32',['CartesianCoordinateSystem2d.idl',['../CartesianCoordinateSystem2d_8idl.html',1,'']]],
   ['cartesiancoordinatesystem3d_2eidl_33',['CartesianCoordinateSystem3d.idl',['../CartesianCoordinateSystem3d_8idl.html',1,'']]],
   ['casemap_2eidl_34',['CaseMap.idl',['../CaseMap_8idl.html',1,'']]],
-  ['cell_2eidl_35',['Cell.idl',['../text_2Cell_8idl.html',1,'(Global Namespace)'],['../table_2Cell_8idl.html',1,'(Global Namespace)']]],
+  ['cell_2eidl_35',['Cell.idl',['../table_2Cell_8idl.html',1,'(Global Namespace)'],['../text_2Cell_8idl.html',1,'(Global Namespace)']]],
   ['celladdress_2eidl_36',['CellAddress.idl',['../CellAddress_8idl.html',1,'']]],
   ['cellannotation_2eidl_37',['CellAnnotation.idl',['../CellAnnotation_8idl.html',1,'']]],
   ['cellannotations_2eidl_38',['CellAnnotations.idl',['../CellAnnotations_8idl.html',1,'']]],
@@ -119,7 +119,7 @@ var searchData=
   ['chartdatarowproperties_2eidl_116',['ChartDataRowProperties.idl',['../ChartDataRowProperties_8idl.html',1,'']]],
   ['chartdatarowsource_2eidl_117',['ChartDataRowSource.idl',['../ChartDataRowSource_8idl.html',1,'']]],
   ['chartdatavalue_2eidl_118',['ChartDataValue.idl',['../ChartDataValue_8idl.html',1,'']]],
-  ['chartdocument_2eidl_119',['ChartDocument.idl',['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
+  ['chartdocument_2eidl_119',['ChartDocument.idl',['../chart2_2ChartDocument_8idl.html',1,'(Global Namespace)'],['../chart_2ChartDocument_8idl.html',1,'(Global Namespace)']]],
   ['chartdocumentwrapper_2eidl_120',['ChartDocumentWrapper.idl',['../ChartDocumentWrapper_8idl.html',1,'']]],
   ['charterrorcategory_2eidl_121',['ChartErrorCategory.idl',['../ChartErrorCategory_8idl.html',1,'']]],
   ['charterrorindicatortype_2eidl_122',['ChartErrorIndicatorType.idl',['../ChartErrorIndicatorType_8idl.html',1,'']]],
@@ -170,7 +170,7 @@ var searchData=
   ['colorscaleentrytype_2eidl_167',['ColorScaleEntryType.idl',['../ColorScaleEntryType_8idl.html',1,'']]],
   ['colorspacetype_2eidl_168',['ColorSpaceType.idl',['../ColorSpaceType_8idl.html',1,'']]],
   ['colortable_2eidl_169',['ColorTable.idl',['../ColorTable_8idl.html',1,'']]],
-  ['column_2eidl_170',['Column.idl',['../sdb_2Column_8idl.html',1,'(Global Namespace)'],['../sdbcx_2Column_8idl.html',1,'(Global Namespace)']]],
+  ['column_2eidl_170',['Column.idl',['../sdbcx_2Column_8idl.html',1,'(Global Namespace)'],['../sdb_2Column_8idl.html',1,'(Global Namespace)']]],
   ['columndescriptor_2eidl_171',['ColumnDescriptor.idl',['../ColumnDescriptor_8idl.html',1,'']]],
   ['columndescriptorcontrol_2eidl_172',['ColumnDescriptorControl.idl',['../ColumnDescriptorControl_8idl.html',1,'']]],
   ['columndescriptorcontrolmodel_2eidl_173',['ColumnDescriptorControlModel.idl',['../ColumnDescriptorControlModel_8idl.html',1,'']]],
@@ -181,7 +181,7 @@ var searchData=
   ['columnvalue_2eidl_178',['ColumnValue.idl',['../ColumnValue_8idl.html',1,'']]],
   ['combinedcharacters_2eidl_179',['CombinedCharacters.idl',['../CombinedCharacters_8idl.html',1,'']]],
   ['combobox_2eidl_180',['ComboBox.idl',['../component_2ComboBox_8idl.html',1,'(Global Namespace)'],['../control_2ComboBox_8idl.html',1,'(Global Namespace)']]],
-  ['command_2eidl_181',['Command.idl',['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../animations_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)']]],
+  ['command_2eidl_181',['Command.idl',['../awt_2Command_8idl.html',1,'(Global Namespace)'],['../ucb_2Command_8idl.html',1,'(Global Namespace)'],['../animations_2Command_8idl.html',1,'(Global Namespace)']]],
   ['commandabortedexception_2eidl_182',['CommandAbortedException.idl',['../CommandAbortedException_8idl.html',1,'']]],
   ['commandbutton_2eidl_183',['CommandButton.idl',['../component_2CommandButton_8idl.html',1,'(Global Namespace)'],['../control_2CommandButton_8idl.html',1,'(Global Namespace)']]],
   ['commanddefinition_2eidl_184',['CommandDefinition.idl',['../CommandDefinition_8idl.html',1,'']]],
@@ -216,7 +216,7 @@ var searchData=
   ['configurationregistry_2eidl_213',['ConfigurationRegistry.idl',['../ConfigurationRegistry_8idl.html',1,'']]],
   ['configurationupdateaccess_2eidl_214',['ConfigurationUpdateAccess.idl',['../ConfigurationUpdateAccess_8idl.html',1,'']]],
   ['connectexception_2eidl_215',['ConnectException.idl',['../ConnectException_8idl.html',1,'']]],
-  ['connection_2eidl_216',['Connection.idl',['../sdb_2Connection_8idl.html',1,'(Global Namespace)'],['../sdbc_2Connection_8idl.html',1,'(Global Namespace)']]],
+  ['connection_2eidl_216',['Connection.idl',['../sdbc_2Connection_8idl.html',1,'(Global Namespace)'],['../sdb_2Connection_8idl.html',1,'(Global Namespace)']]],
   ['connectionlostexception_2eidl_217',['ConnectionLostException.idl',['../ConnectionLostException_8idl.html',1,'']]],
   ['connectionmode_2eidl_218',['ConnectionMode.idl',['../ConnectionMode_8idl.html',1,'']]],
   ['connectionpool_2eidl_219',['ConnectionPool.idl',['../ConnectionPool_8idl.html',1,'']]],
@@ -291,7 +291,7 @@ var searchData=
   ['cryptographyexception_2eidl_288',['CryptographyException.idl',['../CryptographyException_8idl.html',1,'']]],
   ['csvlogformatter_2eidl_289',['CsvLogFormatter.idl',['../CsvLogFormatter_8idl.html',1,'']]],
   ['ctlscripttype_2eidl_290',['CTLScriptType.idl',['../CTLScriptType_8idl.html',1,'']]],
-  ['currency_2eidl_291',['Currency.idl',['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)'],['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)']]],
+  ['currency_2eidl_291',['Currency.idl',['../offapi_2com_2sun_2star_2i18n_2Currency_8idl.html',1,'(Global Namespace)'],['../udkapi_2com_2sun_2star_2bridge_2oleautomation_2Currency_8idl.html',1,'(Global Namespace)']]],
   ['currency2_2eidl_292',['Currency2.idl',['../Currency2_8idl.html',1,'']]],
   ['currencyfield_2eidl_293',['CurrencyField.idl',['../control_2CurrencyField_8idl.html',1,'(Global Namespace)'],['../component_2CurrencyField_8idl.html',1,'(Global Namespace)']]],
   ['curvestyle_2eidl_294',['CurveStyle.idl',['../CurveStyle_8idl.html',1,'']]],
